Computation times — joblib 1.3.2 documentation

# Computation times

00:34.232 total execution time for auto_examples files:

Returning a generator in joblib.Parallel (`parallel_generator.py`) | 00:34.232 | 0.0 MB
Improving I/O using compressors (`compressors_comparison.py`) | 00:00.000 | 0.0 MB
How to use joblib.Memory (`memory_basic_usage.py`) | 00:00.000 | 0.0 MB
Checkpoint using joblib.Memory and joblib.Parallel (`nested_parallel_memory.py`) | 00:00.000 | 0.0 MB
NumPy memmap in joblib.Parallel (`parallel_memmap.py`) | 00:00.000 | 0.0 MB
Random state within joblib.Parallel (`parallel_random_state.py`) | 00:00.000 | 0.0 MB
Serialization of un-picklable objects (`serialization_and_wrappers.py`) | 00:00.000 | 0.0 MB